import subprocess
from enum import Enum
from .paths import seasons
import random
import requests

# import mpv
import tempfile
import os


class Stream(str, Enum):
    KEXP = "kexp"
    KUGS = "kugs"
    CLIS = "clis"


def url_for_time(t) -> str:
    default = "https://kexp-mp3-128.streamguys1.com/kexp128.mp3"
    tz = t.strftime("%Y-%m-%dT%H:%M:%SZ")
    print(f"getting archive: {t}")
    check_url = (
        f"https://api.kexp.org/get_streaming_url/?bitrate=128&timestamp={tz}&location=1"
    )
    response = requests.get(check_url)
    if response.status_code == 200:
        found = response.json().get("sg-url")
        if found is None:
            print(f"error getting archive: {t}")
            return default
    else:
        print(f"error getting archive: {t}")
        return default

    return found


def play(stream, t=None):
    """Play streams using mpv."""
    match stream:
        case Stream.KEXP:
            url = "https://kexp-mp3-128.streamguys1.com/kexp128.mp3"
            if t:
                url = url_for_time(t)
        case Stream.KUGS:
            url = "https://peridot.streamguys1.com:7175/kugs-mp3"
        case Stream.CLIS:
            url = "https://stream2.statsradio.com:8012/stream?=&&___cb=759135934160766"
        case _:
            raise ValueError(f"unrecognized stream: {stream}")
    subprocess.run(["mpv", url])


def local():
    """play random local songs."""
    songs = []
    for d in seasons():
        for f in d.iterdir():
            if not f.suffix == ".mp3":
                continue
            songs.append(f)
    random.shuffle(songs)
    with tempfile.NamedTemporaryFile(delete=False, suffix=".txt") as tmp:
        for song in songs:
            tmp.write(f"{song}\n".encode())
        playlist = tmp.name
        # fd -t file -e mp3 -p -a "fall|winter|spring|summer" $HOME/Music/ | mpv --playlist=- --shuffle --no-video

    try:
        subprocess.run(["mpv", f"--playlist={playlist}", "--shuffle", "--no-video"])
        # process = subprocess.Popen(
        #     ["mpv", f"--playlist={playlist}", "--shuffle", "--no-video"],
        # )

        # process.wait()
    finally:
        os.remove(playlist)
